# __version__.py
# autogenerated by keats 0.2.26
__version__ = "0.0.4"
__name__ = "dasi"
__title__ = "dasi"
__authors__ = ["jvrana <justin.vrana@gmail.com>"]
__repo__ = None
__homepage__ = None
__description__ = ""
